@@ -17,7 +17,6 @@ import getpass
 import time
 
 
-
 class Configuration:
     config_path = os.path.expanduser("~/.cognicept/")
     env_path = config_path + "runtime.env"
@@ -34,9 +33,11 @@ class Configuration:
             return False
 
         #object.config = dotenv_values(dotenv_path=file.name) if sys.version_info.minor > 5 else dotenv_values(dotenv_path=find_dotenv(), verbose=True)
-        object.config = dotenv_values(dotenv_path=object.env_path, verbose = True)
+        object.config = dotenv_values(
+            dotenv_path=object.env_path, verbose=True)
         if(len(object.config) == 0):
-            print("Configuration file `" + object.env_path + "` is empty or could not be parsed.")
+            print("Configuration file `" + object.env_path +
+                  "` is empty or could not be parsed.")
             return False
         object._config_loaded = True
         return True
@@ -46,7 +47,8 @@ class Configuration:
             return
 
         if (not os.access(object.env_path, os.W_OK)):
-            print("Error: You don't have writing permissions for `" + object.env_path + "`. Run as `sudo` or change file permissions.")
+            print("Error: You don't have writing permissions for `" +
+                  object.env_path + "`. Run as `sudo` or change file permissions.")
             return
         if(args.read):
             for key, value in object.config.items():
@@ -62,7 +64,8 @@ class Configuration:
                 # check if matches key specs
                 matches = re.match(object._regex_key, new_key)
                 if matches is None:
-                    print("Error: Key can be uppercase letters, digits, and the '_'. Try again.")
+                    print(
+                        "Error: Key can be uppercase letters, digits, and the '_'. Try again.")
                     new_key = ""
 
             new_value = ""
@@ -77,8 +80,9 @@ class Configuration:
 
             object.config[new_key] = new_value
         elif(args.ssh):
-            if object.configure_ssh():                
-                print ('SSH config done. To apply changes restart agents using `cognicept restart`.')
+            if object.configure_ssh():
+                print(
+                    'SSH config done. To apply changes restart agents using `cognicept restart`.')
         else:
             for key, value in object.config.items():
                 new_value = input(key + "[" + value + "]:")
@@ -93,11 +97,12 @@ class Configuration:
                 for key, value in object.config.items():
                     file.write(key + '=' + value + '\n')
         except IOError:
-            print("Could not write into `" + object.env_path + "`. Please check write permission or run with `sudo`.")
+            print("Could not write into `" + object.env_path +
+                  "`. Please check write permission or run with `sudo`.")
 
     def get_cognicept_credentials(object):
         if "COGNICEPT_ACCESS_KEY" in object.config:
-            return object.config["COGNICEPT_ACCESS_KEY"]   
+            return object.config["COGNICEPT_ACCESS_KEY"]
         else:
             print('COGNICEPT_ACCESS_KEY missing')
 
@@ -112,8 +117,8 @@ class Configuration:
             return object.config[field_name]
         else:
             raise KeyError(field_name)
-        
-    def interpret_bool_input(object,input_string):
+
+    def interpret_bool_input(object, input_string):
         if(input_string == 'Y'):
             return True
         elif(input_string == 'n'):
@@ -126,7 +131,8 @@ class Configuration:
 
         enable_ssh = None
         while(enable_ssh == None):
-            enable_ssh = object.interpret_bool_input(input("Enable SSH access? (Y/n):"))
+            enable_ssh = object.interpret_bool_input(
+                input("Enable SSH access? (Y/n):"))
 
         if(not enable_ssh):
             object.config["COG_ENABLE_SSH"] = "False"
@@ -137,17 +143,20 @@ class Configuration:
         else:
             object.config["COG_ENABLE_SSH"] = "True"
 
-        ssh_authorized_keys_path = os.path.expanduser("~") + "/.ssh/authorized_keys" 
+        ssh_authorized_keys_path = os.path.expanduser(
+            "~") + "/.ssh/authorized_keys"
         print("\n \nSSH key needs to be used for hosts with disabled password login. "
-        "It can also simplify access so you don't need to input the password each time.\n"
-        "This process will generate ssh key locally and mount it to the docker container. "
-        "The public key is copied to `" + ssh_authorized_keys_path + "` to give access.  Root access is needed and you will be prompted for password."
-        "The ssh key is neither sent nor stored to the Cognicept server. "
-        "If you choose not to, manual password ssh access can be still used.")
+              "It can also simplify access so you don't need to input the password each time.\n"
+              "This process will generate ssh key locally and mount it to the docker container. "
+              "The public key is copied to `" + ssh_authorized_keys_path +
+              "` to give access.  Root access is needed and you will be prompted for password."
+              "The ssh key is neither sent nor stored to the Cognicept server. "
+              "If you choose not to, manual password ssh access can be still used.")
 
         enable_ssh_key = None
         while(enable_ssh_key == None):
-            enable_ssh_key = object.interpret_bool_input(input("Generate SSH key and give access? (Y/n):"))
+            enable_ssh_key = object.interpret_bool_input(
+                input("Generate SSH key and give access? (Y/n):"))
 
         if(not enable_ssh_key):
             object.config["COG_ENABLE_SSH_KEY_AUTH"] = "False"
@@ -161,9 +170,10 @@ class Configuration:
                 if not os.path.exists(cognicet_ssh_directory):
                     os.makedirs(cognicet_ssh_directory)
             except:
-                print("Failed. Don't have privileges to create files/directories within the ssh directory.")
+                print(
+                    "Failed. Don't have privileges to create files/directories within the ssh directory.")
                 return False
-            
+
             # generate the keys
             ssh_key = RSA.generate(2048)
             private_key_path = cognicet_ssh_directory + "id_rsa"
@@ -185,7 +195,8 @@ class Configuration:
 
         # retrieve the user name
         while not user_exists:
-            user_name = input("Name of the user to access ssh(if empty, defaults to `" + default_user + "`): ")
+            user_name = input(
+                "Name of the user to access ssh(if empty, defaults to `" + default_user + "`): ")
             if(user_name == ""):
                 user_name = default_user
             object.config["COG_SSH_DEFAULT_USER"] = user_name
@@ -194,45 +205,48 @@ class Configuration:
             if os.path.exists(ssh_directory_path):
                 user_exists = True
             else:
-                print("User " + user_name + " doesn't seem to exist or openssh server is not installed.")
+                print("User " + user_name +
+                      " doesn't seem to exist or openssh server is not installed.")
 
         # copy the keys to authorized_keys file if automatic authentication was enabled
         if object.config["COG_ENABLE_SSH_KEY_AUTH"] == "True":
             authorized_keys_path = ssh_directory_path + "authorized_keys"
             try:
-                print('Root access is needed to modify `' + authorized_keys_path + '` and you will be prompted for password.')
-                proc = subprocess.call(['sudo', 'sh', '-c', 'cat ' + public_key_path + ' >> ' + authorized_keys_path])
+                print('Root access is needed to modify `' +
+                      authorized_keys_path + '` and you will be prompted for password.')
+                proc = subprocess.call(
+                    ['sudo', 'sh', '-c', 'cat ' + public_key_path + ' >> ' + authorized_keys_path])
             except:
                 print("Failed! Don't have access to " + authorized_keys_path)
                 return
 
-
         enable_automatic_ssh = None
         while(enable_automatic_ssh == None):
-            enable_automatic_ssh = object.interpret_bool_input(input("Enable automatic ssh access? (Y/n):"))
-        
+            enable_automatic_ssh = object.interpret_bool_input(
+                input("Enable automatic ssh access? (Y/n):"))
+
         if(not enable_automatic_ssh):
             object.config["COG_ENABLE_AUTOMATIC_SSH"] = "False"
         else:
             object.config["COG_ENABLE_AUTOMATIC_SSH"] = "True"
-        
+
         object.save_config()
         return True
 
     def is_ssh_enabled(object):
         if(not "COG_ENABLE_SSH_KEY_AUTH" in object.config):
             return False
-        
+
         return object.config["COG_ENABLE_SSH_KEY_AUTH"]
 
-    def cognicept_key_rotate(object,args):
+    def cognicept_key_rotate(object, args):
         print("Updating cloud credentials.")
         try:
             headers = {
                 'Authorization': 'Basic ' + object.get_cognicept_credentials()
             }
             resp = requests.get(object.get_cognicept_api_uri(
-            ) + 'aws/assume_role', headers = headers, timeout=5)
+            ) + 'aws/assume_role', headers=headers, timeout=5)
             if resp.status_code != 200:
                 print('Login error: wrong credentials.')
                 return False
@@ -253,7 +267,7 @@ class Configuration:
             print("Cognicept REST API error: Wrong endpoint.")
             return False
         except Exception as e:
-            print("Cognicept REST API error"+ str(e))
+            print("Cognicept REST API error" + str(e))
             raise SystemExit()
         object.save_config()
 
