@@ -46,7 +46,6 @@ class ProgressPercentage(object):
 class Pusher:
 
     def __init__(self):
-        self.s3_client = boto3.client('s3')
         self.bucket_name = 'cognicept-bagfiles'
 
     def push(self, args):
@@ -54,12 +53,33 @@ class Pusher:
         Main push entry point
         """
         if args.bag:
+            # Construct client
+            self.construct_client(args.config)
+            # Push bag
             self.push_bag(args)
         else:
             # start or stop must be provided
             print(
                 bcolors.FAIL + "Required command is missing." + bcolors.ENDC)
 
+    def construct_client(self, config_obj):
+        """
+        Utility function to create S3 client based on runtime.env credentials
+        """
+        local_cfg = config_obj.config
+
+        if 'AWS_SESSION_TOKEN' in local_cfg:
+            self.s3_client = boto3.client(
+                's3', region_name='ap-southeast-1',
+                aws_access_key_id=local_cfg['AWS_ACCESS_KEY_ID'],
+                aws_secret_access_key=local_cfg['AWS_SECRET_ACCESS_KEY'],
+                aws_session_token=local_cfg['AWS_SESSION_TOKEN'])
+        else:
+            self.s3_client = boto3.client(
+                's3', region_name='ap-southeast-1',
+                aws_access_key_id=local_cfg['AWS_ACCESS_KEY_ID'],
+                aws_secret_access_key=local_cfg['AWS_SECRET_ACCESS_KEY'])
+
     def push_bag(self, args):
         """
         Push bag to S3 and bag metadata to Cognicept cloud
@@ -71,7 +91,7 @@ class Pusher:
                 bcolors.OKBLUE +
                 "Uploading latest bag file to S3: " +
                 bcolors.ENDC + bag_file_path)
-            upload_status = self.upload_s3(bag_file_path)
+            upload_status = self.upload_s3(bag_file_path, args.config)
         elif args.bag.endswith('.bag'):
             bag_file_path = os.path.expanduser(args.path+"bags/"+args.bag)
             if(self.check_bag_exists(bag_file_path)):
@@ -79,7 +99,7 @@ class Pusher:
                     bcolors.OKBLUE +
                     "Uploading bag file to S3: " +
                     bcolors.ENDC + bag_file_path)
-                upload_status = self.upload_s3(bag_file_path)
+                upload_status = self.upload_s3(bag_file_path, args.config)
             else:
                 print(
                     bcolors.FAIL +
@@ -100,7 +120,6 @@ class Pusher:
         Get path of the latest bag file
         """
         bag_path = os.path.expanduser(args.path+"bags")
-        # * means all if need specific format then *.csv
         bag_list = glob.glob(bag_path+"/*.bag")
         if bag_list:
             latest_file = max(bag_list, key=os.path.getctime)
@@ -119,21 +138,31 @@ class Pusher:
         else:
             return False
 
-    def upload_s3(self, bag_file_path):
+    def upload_s3(self, bag_file_path, config_obj):
         """
         Upload rosbag to S3
         """
         # Multipart threaded approach for larger files
         config = TransferConfig(multipart_threshold=1024*25, max_concurrency=10,
                                 multipart_chunksize=1024*25, use_threads=True)
-        try:
-            file_name = ntpath.basename(bag_file_path)
-            self.s3_client.upload_file(bag_file_path, self.bucket_name, file_name,
-                                       Config=config, Callback=ProgressPercentage(bag_file_path))
-        except ClientError as e:
-            logging.error(e)
-            return False
-        return True
+        num_retries = 3
+
+        for trial in range(num_retries):
+            try:
+                # Upload file
+                file_name = ntpath.basename(bag_file_path)
+                self.s3_client.upload_file(bag_file_path, self.bucket_name, file_name,
+                                           Config=config, Callback=ProgressPercentage(bag_file_path))
+                # Return true for successful upload
+                return True
+            except boto3.exceptions.S3UploadFailedError:
+                # On failure, retry
+                print('Attempt #' + str(trial+1) + bcolors.FAIL +
+                      " FAILED" + bcolors.ENDC + "\033[K")
+                # Wait for 1 second before retrying
+                time.sleep(1.0)
+        # If the loop is completed, upload failed, so return false
+        return False
 
     def post_bag_metadata(self, args, bag_file_path):
         """
@@ -147,10 +176,16 @@ class Pusher:
             "uploaded_at": datetime.datetime.now().isoformat()
         }
 
-        # retrieve jwt
-        token = args.config.get_cognicept_jwt()
+        # retrieve cognicept access key
+        try:
+            token = args.config.get_field("COGNICEPT_ACCESS_KEY")
+        except KeyError:
+            print(bcolors.FAIL +
+                  'COGNICEPT_ACCESS_KEY variable undefined in configuration. Could not update Cognicept cloud with bag metadata.' +
+                  bcolors.ENDC)
+            raise(SystemExit)
 
-        headers = {"Authorization": "Bearer " + token}
+        headers = {"Authorization": "Basic " + token}
 
         try:
             resp = requests.post(args.config.get_cognicept_api_uri(
@@ -160,7 +195,7 @@ class Pusher:
                 print(
                     'Cognicept REST API error: ' +
                     args.config.get_cognicept_api_uri() +
-                    'responded with ' + str(resp.status_code) +
+                    ' responded with ' + str(resp.status_code) +
                     '\n' + resp.json()['Message'])
                 return False
             else:
@@ -174,6 +209,6 @@ class Pusher:
         except requests.exceptions.TooManyRedirects:
             print("Cognicept REST API error: Wrong endpoint.")
             return False
-        except:
-            print("Cognicept REST API error")
+        except Exception as ex:
+            print("Cognicept REST API error, " + str(ex))
             return False
